@@ -83,11 +83,12 @@ void fill_CKA_table(std::map<unsigned long, std::string> &t)
 	t[CKA_EXPONENT_1] = "CKA_EXPONENT_1";
 	t[CKA_EXPONENT_2] = "CKA_EXPONENT_2";
 	t[CKA_COEFFICIENT] = "CKA_COEFFICIENT";
+	t[CKA_PUBLIC_KEY_INFO] = "CKA_PUBLIC_KEY_INFO";
 	t[CKA_PRIME] = "CKA_PRIME";
 	t[CKA_SUBPRIME] = "CKA_SUBPRIME";
 	t[CKA_BASE] = "CKA_BASE";
 	t[CKA_PRIME_BITS] = "CKA_PRIME_BITS";
-	t[CKA_SUBPRIME_BITS] = "CKA_SUBPRIME_BITS";
+	t[CKA_SUB_PRIME_BITS] = "CKA_SUB_PRIME_BITS";
 	t[CKA_VALUE_BITS] = "CKA_VALUE_BITS";
 	t[CKA_VALUE_LEN] = "CKA_VALUE_LEN";
 	t[CKA_EXTRACTABLE] = "CKA_EXTRACTABLE";
@@ -97,12 +98,16 @@ void fill_CKA_table(std::map<unsigned long, std::string> &t)
 	t[CKA_KEY_GEN_MECHANISM] = "CKA_KEY_GEN_MECHANISM";
 	t[CKA_MODIFIABLE] = "CKA_MODIFIABLE";
 	t[CKA_COPYABLE] = "CKA_COPYABLE";
+	t[CKA_DESTROYABLE] = "CKA_DESTROYABLE";
 	t[CKA_EC_PARAMS] = "CKA_EC_PARAMS";
 	t[CKA_EC_POINT] = "CKA_EC_POINT";
 	t[CKA_SECONDARY_AUTH] = "CKA_SECONDARY_AUTH";
 	t[CKA_AUTH_PIN_FLAGS] = "CKA_AUTH_PIN_FLAGS";
 	t[CKA_ALWAYS_AUTHENTICATE] = "CKA_ALWAYS_AUTHENTICATE";
 	t[CKA_WRAP_WITH_TRUSTED] = "CKA_WRAP_WITH_TRUSTED";
+	t[CKA_WRAP_TEMPLATE] = "CKA_WRAP_TEMPLATE";
+	t[CKA_UNWRAP_TEMPLATE] = "CKA_UNWRAP_TEMPLATE";
+	t[CKA_DERIVE_TEMPLATE] = "CKA_DERIVE_TEMPLATE";
 	t[CKA_OTP_FORMAT] = "CKA_OTP_FORMAT";
 	t[CKA_OTP_LENGTH] = "CKA_OTP_LENGTH";
 	t[CKA_OTP_TIME_INTERVAL] = "CKA_OTP_TIME_INTERVAL";
@@ -137,9 +142,6 @@ void fill_CKA_table(std::map<unsigned long, std::string> &t)
 	t[CKA_REQUIRED_CMS_ATTRIBUTES] = "CKA_REQUIRED_CMS_ATTRIBUTES";
 	t[CKA_DEFAULT_CMS_ATTRIBUTES] = "CKA_DEFAULT_CMS_ATTRIBUTES";
 	t[CKA_SUPPORTED_CMS_ATTRIBUTES] = "CKA_SUPPORTED_CMS_ATTRIBUTES";
-	t[CKA_WRAP_TEMPLATE] = "CKA_WRAP_TEMPLATE";
-	t[CKA_UNWRAP_TEMPLATE] = "CKA_UNWRAP_TEMPLATE";
-	t[CKA_DERIVE_TEMPLATE] = "CKA_DERIVE_TEMPLATE";
 	t[CKA_ALLOWED_MECHANISMS] = "CKA_ALLOWED_MECHANISMS";
 	// local extensions
 	t[CKA_VENDOR_SOFTHSM] = "CKA_VENDOR_SOFTHSM";
@@ -188,6 +190,18 @@ void fill_CKM_table(std::map<unsigned long, std::string> &t)
 	t[CKM_SHA512_RSA_PKCS_PSS] = "CKM_SHA512_RSA_PKCS_PSS";
 	t[CKM_SHA224_RSA_PKCS] = "CKM_SHA224_RSA_PKCS";
 	t[CKM_SHA224_RSA_PKCS_PSS] = "CKM_SHA224_RSA_PKCS_PSS";
+	t[CKM_SHA512_224] = "CKM_SHA512_224";
+	t[CKM_SHA512_224_HMAC] = "CKM_SHA512_224_HMAC";
+	t[CKM_SHA512_224_HMAC_GENERAL] = "CKM_SHA512_224_HMAC_GENERAL";
+	t[CKM_SHA512_224_KEY_DERIVATION] = "CKM_SHA512_224_KEY_DERIVATION";
+	t[CKM_SHA512_256] = "CKM_SHA512_256";
+	t[CKM_SHA512_256_HMAC] = "CKM_SHA512_256_HMAC";
+	t[CKM_SHA512_256_HMAC_GENERAL] = "CKM_SHA512_256_HMAC_GENERAL";
+	t[CKM_SHA512_256_KEY_DERIVATION] = "CKM_SHA512_256_KEY_DERIVATION";
+	t[CKM_SHA512_T] = "CKM_SHA512_T";
+	t[CKM_SHA512_T_HMAC] = "CKM_SHA512_T_HMAC";
+	t[CKM_SHA512_T_HMAC_GENERAL] = "CKM_SHA512_T_HMAC_GENERAL";
+	t[CKM_SHA512_T_KEY_DERIVATION] = "CKM_SHA512_T_KEY_DERIVATION";
 	t[CKM_RC2_KEY_GEN] = "CKM_RC2_KEY_GEN";
 	t[CKM_RC2_ECB] = "CKM_RC2_ECB";
 	t[CKM_RC2_CBC] = "CKM_RC2_CBC";
@@ -266,17 +280,11 @@ void fill_CKM_table(std::map<unsigned long, std::string> &t)
 	t[CKM_CAST3_MAC] = "CKM_CAST3_MAC";
 	t[CKM_CAST3_MAC_GENERAL] = "CKM_CAST3_MAC_GENERAL";
 	t[CKM_CAST3_CBC_PAD] = "CKM_CAST3_CBC_PAD";
-	t[CKM_CAST5_KEY_GEN] = "CKM_CAST5_KEY_GEN";
 	t[CKM_CAST128_KEY_GEN] = "CKM_CAST128_KEY_GEN";
-	t[CKM_CAST5_ECB] = "CKM_CAST5_ECB";
 	t[CKM_CAST128_ECB] = "CKM_CAST128_ECB";
-	t[CKM_CAST5_CBC] = "CKM_CAST5_CBC";
 	t[CKM_CAST128_CBC] = "CKM_CAST128_CBC";
-	t[CKM_CAST5_MAC] = "CKM_CAST5_MAC";
 	t[CKM_CAST128_MAC] = "CKM_CAST128_MAC";
-	t[CKM_CAST5_MAC_GENERAL] = "CKM_CAST5_MAC_GENERAL";
 	t[CKM_CAST128_MAC_GENERAL] = "CKM_CAST128_MAC_GENERAL";
-	t[CKM_CAST5_CBC_PAD] = "CKM_CAST5_CBC_PAD";
 	t[CKM_CAST128_CBC_PAD] = "CKM_CAST128_CBC_PAD";
 	t[CKM_RC5_KEY_GEN] = "CKM_RC5_KEY_GEN";
 	t[CKM_RC5_ECB] = "CKM_RC5_ECB";
@@ -318,9 +326,7 @@ void fill_CKM_table(std::map<unsigned long, std::string> &t)
 	t[CKM_PBE_MD5_DES_CBC] = "CKM_PBE_MD5_DES_CBC";
 	t[CKM_PBE_MD5_CAST_CBC] = "CKM_PBE_MD5_CAST_CBC";
 	t[CKM_PBE_MD5_CAST3_CBC] = "CKM_PBE_MD5_CAST3_CBC";
-	t[CKM_PBE_MD5_CAST5_CBC] = "CKM_PBE_MD5_CAST5_CBC";
 	t[CKM_PBE_MD5_CAST128_CBC] = "CKM_PBE_MD5_CAST128_CBC";
-	t[CKM_PBE_SHA1_CAST5_CBC] = "CKM_PBE_SHA1_CAST5_CBC";
 	t[CKM_PBE_SHA1_CAST128_CBC] = "CKM_PBE_SHA1_CAST128_CBC";
 	t[CKM_PBE_SHA1_RC4_128] = "CKM_PBE_SHA1_RC4_128";
 	t[CKM_PBE_SHA1_RC4_40] = "CKM_PBE_SHA1_RC4_40";
@@ -336,6 +342,16 @@ void fill_CKM_table(std::map<unsigned long, std::string> &t)
 	t[CKM_WTLS_PRF] = "CKM_WTLS_PRF";
 	t[CKM_WTLS_SERVER_KEY_AND_MAC_DERIVE] = "CKM_WTLS_SERVER_KEY_AND_MAC_DERIVE";
 	t[CKM_WTLS_CLIENT_KEY_AND_MAC_DERIVE] = "CKM_WTLS_CLIENT_KEY_AND_MAC_DERIVE";
+	t[CKM_TLS10_MAC_SERVER] = "CKM_TLS10_MAC_SERVER";
+	t[CKM_TLS10_MAC_CLIENT] = "CKM_TLS10_MAC_CLIENT";
+	t[CKM_TLS12_MAC] = "CKM_TLS12_MAC";
+	t[CKM_TLS12_KDF] = "CKM_TLS12_KDF";
+	t[CKM_TLS12_MASTER_KEY_DERIVE] = "CKM_TLS12_MASTER_KEY_DERIVE";
+	t[CKM_TLS12_KEY_AND_MAC_DERIVE] = "CKM_TLS12_KEY_AND_MAC_DERIVE";
+	t[CKM_TLS12_MASTER_KEY_DERIVE_DH] = "CKM_TLS12_MASTER_KEY_DERIVE_DH";
+	t[CKM_TLS12_KEY_SAFE_DERIVE] = "CKM_TLS12_KEY_SAFE_DERIVE";
+	t[CKM_TLS_MAC] = "CKM_TLS_MAC";
+	t[CKM_TLS_KDF] = "CKM_TLS_KDF";
 	t[CKM_KEY_WRAP_LYNKS] = "CKM_KEY_WRAP_LYNKS";
 	t[CKM_KEY_WRAP_SET_OAEP] = "CKM_KEY_WRAP_SET_OAEP";
 	t[CKM_CMS_SIG] = "CKM_CMS_SIG";
@@ -388,7 +404,6 @@ void fill_CKM_table(std::map<unsigned long, std::string> &t)
 	t[CKM_BATON_COUNTER] = "CKM_BATON_COUNTER";
 	t[CKM_BATON_SHUFFLE] = "CKM_BATON_SHUFFLE";
 	t[CKM_BATON_WRAP] = "CKM_BATON_WRAP";
-	t[CKM_ECDSA_KEY_PAIR_GEN] = "CKM_ECDSA_KEY_PAIR_GEN";
 	t[CKM_EC_KEY_PAIR_GEN] = "CKM_EC_KEY_PAIR_GEN";
 	t[CKM_ECDSA] = "CKM_ECDSA";
 	t[CKM_ECDSA_SHA1] = "CKM_ECDSA_SHA1";
@@ -399,6 +414,8 @@ void fill_CKM_table(std::map<unsigned long, std::string> &t)
 	t[CKM_ECDH1_DERIVE] = "CKM_ECDH1_DERIVE";
 	t[CKM_ECDH1_COFACTOR_DERIVE] = "CKM_ECDH1_COFACTOR_DERIVE";
 	t[CKM_ECMQV_DERIVE] = "CKM_ECMQV_DERIVE";
+	t[CKM_ECDH_AES_KEY_WRAP] = "CKM_ECDH_AES_KEY_WRAP";
+	t[CKM_RSA_AES_KEY_WRAP] = "CKM_RSA_AES_KEY_WRAP";
 	t[CKM_JUNIPER_KEY_GEN] = "CKM_JUNIPER_KEY_GEN";
 	t[CKM_JUNIPER_ECB128] = "CKM_JUNIPER_ECB128";
 	t[CKM_JUNIPER_CBC128] = "CKM_JUNIPER_CBC128";
@@ -418,9 +435,10 @@ void fill_CKM_table(std::map<unsigned long, std::string> &t)
 	t[CKM_AES_CTS] = "CKM_AES_CTS";
 	t[CKM_AES_CMAC] = "CKM_AES_CMAC";
 	t[CKM_AES_CMAC_GENERAL] = "CKM_AES_CMAC_GENERAL";
-	t[CKM_AES_KEY_WRAP] = "CKM_AES_KEY_WRAP";
+	t[CKM_AES_XCBC_MAC] = "CKM_AES_XCBC_MAC";
+	t[CKM_AES_XCBC_MAC_96] = "CKM_AES_XCBC_MAC_96";
+	t[CKM_AES_GMAC] = "CKM_AES_GMAC";
 	t[CKM_BLOWFISH_KEY_GEN] = "CKM_BLOWFISH_KEY_GEN";
-	t[CKM_AES_KEY_WRAP_PAD] = "CKM_AES_KEY_WRAP_PAD";
 	t[CKM_BLOWFISH_CBC] = "CKM_BLOWFISH_CBC";
 	t[CKM_TWOFISH_KEY_GEN] = "CKM_TWOFISH_KEY_GEN";
 	t[CKM_TWOFISH_CBC] = "CKM_TWOFISH_CBC";
@@ -447,12 +465,19 @@ void fill_CKM_table(std::map<unsigned long, std::string> &t)
 	t[CKM_DSA_PARAMETER_GEN] = "CKM_DSA_PARAMETER_GEN";
 	t[CKM_DH_PKCS_PARAMETER_GEN] = "CKM_DH_PKCS_PARAMETER_GEN";
 	t[CKM_X9_42_DH_PARAMETER_GEN] = "CKM_X9_42_DH_PARAMETER_GEN";
+	t[CKM_DSA_PROBABLISTIC_PARAMETER_GEN] = "CKM_DSA_PROBABLISTIC_PARAMETER_GEN";
+	t[CKM_DSA_SHAWE_TAYLOR_PARAMETER_GEN] = "CKM_DSA_SHAWE_TAYLOR_PARAMETER_GEN";
 	t[CKM_AES_OFB] = "CKM_AES_OFB";
 	t[CKM_AES_CFB64] = "CKM_AES_CFB64";
 	t[CKM_AES_CFB8] = "CKM_AES_CFB8";
 	t[CKM_AES_CFB128] = "CKM_AES_CFB128";
+	t[CKM_AES_CFB1] = "CKM_AES_CFB1";
+	t[CKM_AES_KEY_WRAP] = "CKM_AES_KEY_WRAP";
+	t[CKM_AES_KEY_WRAP_PAD] = "CKM_AES_KEY_WRAP_PAD";
 	t[CKM_RSA_PKCS_TPM_1_1] = "CKM_RSA_PKCS_TPM_1_1";
-	t[CKM_RSA_PKCS_OAEPTPM_1_1] = "CKM_RSA_PKCS_OAEPTPM_1_1";
+	t[CKM_RSA_PKCS_OAEP_TPM_1_1] = "CKM_RSA_PKCS_OAEP_TPM_1_1";
+	t[CKM_EC_EDWARDS_KEY_PAIR_GEN] = "CKM_EC_EDWARDS_KEY_PAIR_GEN";
+	t[CKM_EDDSA] = "CKM_EDDSA";
 }
 
 void fill_CKO_table(std::map<unsigned long, std::string> &t)
@@ -491,7 +516,6 @@ void fill_CKK_table(std::map<unsigned long, std::string> &t)
 	t[CKK_DES3] = "CKK_DES3";
 	t[CKK_CAST] = "CKK_CAST";
 	t[CKK_CAST3] = "CKK_CAST3";
-	t[CKK_CAST5] = "CKK_CAST5";
 	t[CKK_CAST128] = "CKK_CAST128";
 	t[CKK_RC5] = "CKK_RC5";
 	t[CKK_IDEA] = "CKK_IDEA";
@@ -519,6 +543,7 @@ void fill_CKK_table(std::map<unsigned long, std::string> &t)
 	t[CKK_GOSTR3410] = "CKK_GOSTR3410";
 	t[CKK_GOSTR3411] = "CKK_GOSTR3411";
 	t[CKK_GOST28147] = "CKK_GOST28147";
+	t[CKK_EC_EDWARDS] = "CKK_EC_EDWARDS";
 }
 
 void fill_CKC_table(std::map<unsigned long, std::string> &t)
