@@ -113,6 +113,7 @@ void usage()
 	printf("  -v                Show version info.\n");
 	printf("  --version         Show version info.\n");
 	printf("Options:\n");
+	printf("  --aes             Used to tell import to use file as is and import it as AES.\n");
 	printf("  --file-pin <PIN>  Supply a PIN if the file is encrypted.\n");
 	printf("  --force           Used to override a warning.\n");
 	printf("  --free            Use the first free/uninitialized token.\n");
@@ -148,7 +149,8 @@ enum {
 	OPT_SLOT,
 	OPT_SO_PIN,
 	OPT_TOKEN,
-	OPT_VERSION
+	OPT_VERSION,
+	OPT_AES
 };
 
 // Text representation of the long options
@@ -171,6 +173,7 @@ static const struct option long_options[] = {
 	{ "so-pin",          1, NULL, OPT_SO_PIN },
 	{ "token",           1, NULL, OPT_TOKEN },
 	{ "version",         0, NULL, OPT_VERSION },
+	{ "aes",             0, NULL, OPT_AES },
 	{ NULL,              0, NULL, 0 }
 };
 
@@ -196,6 +199,7 @@ int main(int argc, char* argv[])
 	int forceExec = 0;
 	bool freeToken = false;
 	int noPublicKey = 0;
+	bool importAES = false;
 
 	int doInitToken = 0;
 	int doShowSlots = 0;
@@ -229,6 +233,9 @@ int main(int argc, char* argv[])
 				inPath = optarg;
 				needP11 = true;
 				break;
+			case OPT_AES:
+				importAES = true;
+				break;
 			case OPT_DELETE_TOKEN:
 				doDeleteToken = 1;
 				action++;
@@ -292,11 +299,19 @@ int main(int argc, char* argv[])
 
 	if (needP11)
 	{
+		// Check the basic setup of SoftHSM
+		if (!checkSetup())
+		{
+			fprintf(stderr, "ERROR: Please verify that the SoftHSM configuration is correct.\n");
+			exit(1);
+		}
+
 		// Get a pointer to the function list for PKCS#11 library
 		CK_C_GetFunctionList pGetFunctionList = loadLibrary(module, &moduleHandle, &errMsg);
 		if (!pGetFunctionList)
 		{
-			fprintf(stderr, "ERROR: Could not load the library: %s\n", errMsg);
+			fprintf(stderr, "ERROR: Could not load the PKCS#11 library/module: %s\n", errMsg);
+			fprintf(stderr, "ERROR: Please check log files for additional information.\n");
 			exit(1);
 		}
 
@@ -307,7 +322,8 @@ int main(int argc, char* argv[])
 		CK_RV p11rv = p11->C_Initialize(NULL_PTR);
 		if (p11rv != CKR_OK)
 		{
-			fprintf(stderr, "ERROR: Could not initialize the library.\n");
+			fprintf(stderr, "ERROR: Could not initialize the PKCS#11 library/module: %s\n", module ? module : DEFAULT_PKCS11_LIB);
+			fprintf(stderr, "ERROR: Please check log files for additional information.\n");
 			exit(1);
 		}
 	}
@@ -336,8 +352,8 @@ int main(int argc, char* argv[])
 		rv = findSlot(slot, serial, token, slotID);
 		if (!rv)
 		{
-			rv = importKeyPair(inPath, filePIN, slotID, userPIN, label, objectID,
-						forceExec, noPublicKey);
+			rv = importAES ? importSecretKey(inPath, slotID, userPIN, label, objectID)
+					: importKeyPair(inPath, filePIN, slotID, userPIN, label, objectID, forceExec, noPublicKey);
 		}
 	}
 
@@ -364,6 +380,31 @@ int main(int argc, char* argv[])
 	return rv;
 }
 
+// Check the basic setup of SoftHSM
+bool checkSetup()
+{
+	// Initialize the SoftHSM internal functions
+	if (!initSoftHSM())
+	{
+		finalizeSoftHSM();
+		return false;
+	}
+
+	std::string basedir = Configuration::i()->getString("directories.tokendir", DEFAULT_TOKENDIR);
+
+	// Try open the token directory
+	Directory storeDir(basedir);
+	if (!storeDir.isValid())
+	{
+		fprintf(stderr, "ERROR: Failed to enumerate object store in %s\n", basedir.c_str());
+		finalizeSoftHSM();
+		return false;
+	}
+
+	finalizeSoftHSM();
+	return true;
+}
+
 // Initialize the token
 int initToken(CK_SLOT_ID slotID, char* label, char* soPIN, char* userPIN)
 {
@@ -422,7 +463,8 @@ int initToken(CK_SLOT_ID slotID, char* label, char* soPIN, char* userPIN)
 			return 1;
 			break;
 		default:
-			fprintf(stderr, "ERROR %X: Could not initialize the token.\n", (unsigned int)rv);
+			fprintf(stderr, "ERROR rv=0x%08X: Could not initialize the token.\n", (unsigned int)rv);
+			fprintf(stderr, "Please check log files for additional information.\n");
 			return 1;
 			break;
 	}
@@ -449,7 +491,39 @@ int initToken(CK_SLOT_ID slotID, char* label, char* soPIN, char* userPIN)
 		return 1;
 	}
 
-	printf("The token has been initialized.\n");
+	// Get the token info
+	CK_TOKEN_INFO tokenInfo;
+	rv = p11->C_GetTokenInfo(slotID, &tokenInfo);
+	if (rv != CKR_OK)
+	{
+		fprintf(stderr, "ERROR: Could not get info about the initialized token in slot %lu.\n", slotID);
+		return 1;
+	}
+
+	// Reload the library
+	p11->C_Finalize(NULL_PTR);
+	rv = p11->C_Initialize(NULL_PTR);
+	if (rv != CKR_OK)
+	{
+		fprintf(stderr, "ERROR: Could not initialize the library.\n");
+		return 1;
+	}
+
+	// Get the slotID
+	CK_SLOT_ID newSlotID;
+	if (findSlot(tokenInfo, newSlotID))
+	{
+		return 1;
+	}
+
+	if (slotID == newSlotID)
+	{
+		printf("The token has been initialized on slot %lu\n", newSlotID);
+	}
+	else
+	{
+		printf("The token has been initialized and is reassigned to slot %lu\n", newSlotID);
+	}
 
 	return 0;
 }
@@ -600,7 +674,7 @@ bool findTokenDirectory(std::string basedir, std::string& tokendir, char* serial
 
 	if (!storeDir.isValid())
 	{
-		fprintf(stderr, "Failed to enumerate object store in %s", basedir.c_str());
+		fprintf(stderr, "Failed to enumerate object store in %s\n", basedir.c_str());
 
 		return false;
 	}
@@ -685,7 +759,7 @@ bool rmdir(std::string path)
 
 	if (dir == NULL)
 	{
-		fprintf(stderr, "ERROR: Failed to open directory %s", path.c_str());
+		fprintf(stderr, "ERROR: Failed to open directory %s\n", path.c_str());
 		return false;
 	}
 
@@ -772,7 +846,7 @@ bool rmdir(std::string path)
 		if (errno == ENOENT)
 			goto finished;
 
-		fprintf(stderr, "ERROR: Failed to open directory %s", path.c_str());
+		fprintf(stderr, "ERROR: Failed to open directory %s\n", path.c_str());
 
 		return false;
 	}
@@ -1042,6 +1116,76 @@ int importKeyPair
 	return result;
 }
 
+// Import a secret key from given path
+int importSecretKey(char* filePath, CK_SLOT_ID slotID, char* userPIN, char* label, char* objectID)
+{
+	char user_pin_copy[MAX_PIN_LEN+1];
+
+	if (label == NULL)
+	{
+		fprintf(stderr, "ERROR: A label for the object must be supplied. "
+				"Use --label <text>\n");
+		return 1;
+	}
+
+	if (objectID == NULL)
+	{
+		fprintf(stderr, "ERROR: An ID for the object must be supplied. "
+				"Use --id <hex>\n");
+		return 1;
+	}
+
+	size_t objIDLen = 0;
+	char* objID = hexStrToBin(objectID, strlen(objectID), &objIDLen);
+	if (objID == NULL)
+	{
+		fprintf(stderr, "Please edit --id <hex> to correct error.\n");
+		return 1;
+	}
+
+	// Get the password
+	if (getPW(userPIN, user_pin_copy, CKU_USER) != 0)
+	{
+		fprintf(stderr, "ERROR: Could not get user PIN\n");
+		return 1;
+	}
+
+	CK_SESSION_HANDLE hSession;
+	CK_RV rv = p11->C_OpenSession(slotID, CKF_SERIAL_SESSION | CKF_RW_SESSION,
+					NULL_PTR, NULL_PTR, &hSession);
+	if (rv != CKR_OK)
+	{
+		if (rv == CKR_SLOT_ID_INVALID)
+		{
+			fprintf(stderr, "ERROR: The given slot does not exist.\n");
+		}
+		else
+		{
+			fprintf(stderr, "ERROR: Could not open a session on the given slot.\n");
+		}
+		return 1;
+	}
+
+	rv = p11->C_Login(hSession, CKU_USER, (CK_UTF8CHAR_PTR)user_pin_copy, strlen(user_pin_copy));
+	if (rv != CKR_OK)
+	{
+		if (rv == CKR_PIN_INCORRECT) {
+			fprintf(stderr, "ERROR: The given user PIN does not match the one in the token.\n");
+		}
+		else
+		{
+			fprintf(stderr, "ERROR: Could not log in on the token.\n");
+		}
+		return 1;
+	}
+
+	crypto_init();
+	int result = crypto_import_aes_key(hSession, filePath, label, objID, objIDLen);
+	crypto_final();
+
+	return result;
+}
+
 // Convert a char array of hexadecimal characters into a binary representation
 char* hexStrToBin(char* objectID, int idLength, size_t* newLen)
 {
