@@ -193,6 +193,13 @@ private:
 	SessionManager* sessionManager;
 	HandleManager* handleManager;
 
+	// A list with the supported mechanisms
+	std::map<std::string, CK_MECHANISM_TYPE> mechanisms_table;
+	std::list<CK_MECHANISM_TYPE> supportedMechanisms;
+	CK_ULONG nrSupportedMechanisms;
+
+	int forkID;
+
 	// Encrypt/Decrypt variants
 	CK_RV SymEncryptInit(CK_SESSION_HANDLE hSession, CK_MECHANISM_PTR pMechanism, CK_OBJECT_HANDLE hKey);
 	CK_RV AsymEncryptInit(CK_SESSION_HANDLE hSession, CK_MECHANISM_PTR pMechanism, CK_OBJECT_HANDLE hKey);
@@ -476,6 +483,8 @@ private:
 
 	CK_RV MechParamCheckRSAPKCSOAEP(CK_MECHANISM_PTR pMechanism);
 
-	static bool isMechanismPermitted(OSObject* key, CK_MECHANISM_PTR pMechanism);
+	bool isMechanismPermitted(OSObject* key, CK_MECHANISM_PTR pMechanism);
+	void prepareSupportedMecahnisms(std::map<std::string, CK_MECHANISM_TYPE> &t);
+	bool detectFork(void);
 };
 
