@@ -43,22 +43,12 @@ class BotanDH_PrivateKey : public Botan::DH_PublicKey,
 			   public virtual Botan::DL_Scheme_PrivateKey
 {
 public:
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
-	std::vector<Botan::byte> public_value() const;
-#else
-	Botan::MemoryVector<Botan::byte> public_value() const;
-#endif
+	std::vector<uint8_t> public_value() const;
 
 	// Constructors
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
 	BotanDH_PrivateKey(const Botan::AlgorithmIdentifier& alg_id,
-			   const Botan::secure_vector<Botan::byte>& key_bits,
+			   const Botan::secure_vector<uint8_t>& key_bits,
 			   Botan::RandomNumberGenerator& rng);
-#else
-	BotanDH_PrivateKey(const Botan::AlgorithmIdentifier& alg_id,
-			   const Botan::MemoryRegion<Botan::byte>& key_bits,
-			   Botan::RandomNumberGenerator& rng);
-#endif
 
 	BotanDH_PrivateKey(Botan::RandomNumberGenerator& rng,
 			   const Botan::DL_Group& grp,
