@@ -137,11 +137,7 @@ ByteString BotanDSAPrivateKey::PKCS8Encode()
 	ByteString der;
 	createBotanKey();
 	if (dsa == NULL) return der;
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
-	const Botan::secure_vector<Botan::byte> ber = Botan::PKCS8::BER_encode(*dsa);
-#else
-	const Botan::SecureVector<Botan::byte> ber = Botan::PKCS8::BER_encode(*dsa);
-#endif
+	const auto ber = Botan::PKCS8::BER_encode(*dsa);
 	der.resize(ber.size());
 	memcpy(&der[0], &ber[0], ber.size());
 	return der;
@@ -152,11 +148,7 @@ bool BotanDSAPrivateKey::PKCS8Decode(const ByteString& ber)
 {
 	Botan::DataSource_Memory source(ber.const_byte_str(), ber.size());
 	if (source.end_of_data()) return false;
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
-	Botan::secure_vector<Botan::byte> keydata;
-#else
-	Botan::SecureVector<Botan::byte> keydata;
-#endif
+	Botan::secure_vector<uint8_t> keydata;
 	Botan::AlgorithmIdentifier alg_id;
 	Botan::DSA_PrivateKey* key = NULL;
 	try
@@ -177,12 +169,7 @@ bool BotanDSAPrivateKey::PKCS8Decode(const ByteString& ber)
 
 			return false;
 		}
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,34)
 		key = new Botan::DSA_PrivateKey(alg_id, keydata);
-#else
-		BotanRNG* rng = (BotanRNG*)BotanCryptoFactory::i()->getRNG();
-		key = new Botan::DSA_PrivateKey(alg_id, keydata, *rng->getRNG());
-#endif
 		if (key == NULL) return false;
 
 		setFromBotan(key);
