@@ -106,13 +106,8 @@ bool BotanRSA::sign(PrivateKey* privateKey, const ByteString& dataToSign,
 
 	try
 	{
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,33)
 		BotanRNG* rng = (BotanRNG*)BotanCryptoFactory::i()->getRNG();
 		signer = new Botan::PK_Signer(*botanKey, *rng->getRNG(), emsa);
-#else
-		signer = new Botan::PK_Signer(*botanKey, emsa);
-#endif
-		// Should we add DISABLE_FAULT_PROTECTION? Makes this operation faster.
 	}
 	catch (...)
 	{
@@ -122,11 +117,7 @@ bool BotanRSA::sign(PrivateKey* privateKey, const ByteString& dataToSign,
 	}
 
 	// Perform the signature operation
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
-	std::vector<Botan::byte> signResult;
-#else
-	Botan::SecureVector<Botan::byte> signResult;
-#endif
+	std::vector<uint8_t> signResult;
 	try
 	{
 		BotanRNG* rng = (BotanRNG*)BotanCryptoFactory::i()->getRNG();
@@ -144,11 +135,7 @@ bool BotanRSA::sign(PrivateKey* privateKey, const ByteString& dataToSign,
 
 	// Return the result
 	signature.resize(signResult.size());
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
 	memcpy(&signature[0], signResult.data(), signResult.size());
-#else
-	memcpy(&signature[0], signResult.begin(), signResult.size());
-#endif
 
 	delete signer;
 	signer = NULL;
@@ -336,13 +323,8 @@ bool BotanRSA::signInit(PrivateKey* privateKey, const AsymMech::Type mechanism,
 
 	try
 	{
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,33)
 		BotanRNG* rng = (BotanRNG*)BotanCryptoFactory::i()->getRNG();
 		signer = new Botan::PK_Signer(*botanKey, *rng->getRNG(), emsa);
-#else
-		signer = new Botan::PK_Signer(*botanKey, emsa);
-#endif
-		// Should we add DISABLE_FAULT_PROTECTION? Makes this operation faster.
 	}
 	catch (...)
 	{
@@ -396,11 +378,7 @@ bool BotanRSA::signFinal(ByteString& signature)
 	}
 
 	// Perform the signature operation
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
-	std::vector<Botan::byte> signResult;
-#else
-	Botan::SecureVector<Botan::byte> signResult;
-#endif
+	std::vector<uint8_t> signResult;
 	try
 	{
 		BotanRNG* rng = (BotanRNG*)BotanCryptoFactory::i()->getRNG();
@@ -418,11 +396,7 @@ bool BotanRSA::signFinal(ByteString& signature)
 
 	// Return the result
 	signature.resize(signResult.size());
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
 	memcpy(&signature[0], signResult.data(), signResult.size());
-#else
-	memcpy(&signature[0], signResult.begin(), signResult.size());
-#endif
 
 	delete signer;
 	signer = NULL;
@@ -812,12 +786,8 @@ bool BotanRSA::encrypt(PublicKey* publicKey, const ByteString& data,
 	Botan::PK_Encryptor_EME* encryptor = NULL;
 	try
 	{
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,33)
 		BotanRNG* rng = (BotanRNG*)BotanCryptoFactory::i()->getRNG();
 		encryptor = new Botan::PK_Encryptor_EME(*botanKey, *rng->getRNG(), eme);
-#else
-		encryptor = new Botan::PK_Encryptor_EME(*botanKey, eme);
-#endif
 	}
 	catch (...)
 	{
@@ -827,11 +797,7 @@ bool BotanRSA::encrypt(PublicKey* publicKey, const ByteString& data,
 	}
 
 	// Perform the encryption operation
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
-	std::vector<Botan::byte> encResult;
-#else
-	Botan::SecureVector<Botan::byte> encResult;
-#endif
+	std::vector<uint8_t> encResult;
 	try
 	{
 		BotanRNG* rng = (BotanRNG*)BotanCryptoFactory::i()->getRNG();
@@ -848,11 +814,7 @@ bool BotanRSA::encrypt(PublicKey* publicKey, const ByteString& data,
 
 	// Return the result
 	encryptedData.resize(encResult.size());
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
 	memcpy(&encryptedData[0], encResult.data(), encResult.size());
-#else
-	memcpy(&encryptedData[0], encResult.begin(), encResult.size());
-#endif
 
 	delete encryptor;
 
@@ -903,12 +865,8 @@ bool BotanRSA::decrypt(PrivateKey* privateKey, const ByteString& encryptedData,
 	Botan::PK_Decryptor_EME* decryptor = NULL;
 	try
 	{
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,33)
 		BotanRNG* rng = (BotanRNG*)BotanCryptoFactory::i()->getRNG();
 		decryptor = new Botan::PK_Decryptor_EME(*botanKey, *rng->getRNG(), eme);
-#else
-		decryptor = new Botan::PK_Decryptor_EME(*botanKey, eme);
-#endif
 	}
 	catch (...)
 	{
@@ -918,11 +876,7 @@ bool BotanRSA::decrypt(PrivateKey* privateKey, const ByteString& encryptedData,
 	}
 
 	// Perform the decryption operation
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
-	Botan::secure_vector<Botan::byte> decResult;
-#else
-	Botan::SecureVector<Botan::byte> decResult;
-#endif
+	Botan::secure_vector<uint8_t> decResult;
 	try
 	{
 		decResult = decryptor->decrypt(encryptedData.const_byte_str(), encryptedData.size());
@@ -943,20 +897,12 @@ bool BotanRSA::decrypt(PrivateKey* privateKey, const ByteString& encryptedData,
 		int modSize = pk->getN().size();
 		int decSize = decResult.size();
 		data.resize(modSize);
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
 		memcpy(&data[0] + modSize - decSize, decResult.data(), decSize);
-#else
-		memcpy(&data[0] + modSize - decSize, decResult.begin(), decSize);
-#endif
 	}
 	else
 	{
 		data.resize(decResult.size());
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,0)
 		memcpy(&data[0], decResult.data(), decResult.size());
-#else
-		memcpy(&data[0], decResult.begin(), decResult.size());
-#endif
 	}
 
 	delete decryptor;
