@@ -39,22 +39,42 @@
 #include <iostream>
 
 #include <botan/symkey.h>
-#include <botan/botan.h>
+#include <botan/parsing.h>
 #include <botan/version.h>
-
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(1,11,14)
-#include <botan/key_filt.h>
-#endif
-
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(2,0,0)
-#include "Botan_ecb.h"
-#include <botan/cipher_filter.h>
-#endif
-
-#ifdef WITH_AES_GCM
+#include <botan/filters.h>
 #include <botan/aead.h>
+
+#include "Botan_ecb.h"
+
+#if BOTAN_VERSION_CODE <= BOTAN_VERSION_CODE_FOR(2,11,0)
+   #include <botan/cipher_filter.h>
 #endif
 
+std::vector<std::string> split_on_delim(const std::string& str, char delim)
+{
+	std::vector<std::string> elems;
+	if(str.empty()) return elems;
+
+	std::string substr;
+	for (auto i = str.begin(); i != str.end(); ++i)
+	{
+		if (*i == delim)
+		{
+			if (!substr.empty())
+				elems.push_back(substr);
+			substr.clear();
+		}
+		else
+			substr += *i;
+	}
+
+	if (!substr.empty())
+		elems.push_back(substr);
+
+	return elems;
+}
+
+
 // Constructor
 BotanSymmetricAlgorithm::BotanSymmetricAlgorithm()
 {
@@ -151,28 +171,23 @@ bool BotanSymmetricAlgorithm::encryptInit(const SymmetricKey* key, const SymMode
 		Botan::SymmetricKey botanKey = Botan::SymmetricKey(key->getKeyBits().const_byte_str(), key->getKeyBits().size());
 		if (mode == SymMode::ECB)
 		{
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(2,0,0)
 			// ECB cipher mode was dropped in Botan 2.0
-			const std::vector<std::string> algo_parts = Botan::split_on(cipherName, '/');
+			const std::vector<std::string> algo_parts = split_on_delim(cipherName, '/');
 			const std::string cipher_name = algo_parts[0];
-			Botan::BlockCipherModePaddingMethod* pad;
+			bool with_pkcs7_padding;
 			if (algo_parts.size() == 3 && algo_parts[2] == "PKCS7")
 			{
-				pad = new Botan::PKCS7_Padding();
+				with_pkcs7_padding = true;
 			}
 			else
 			{
-				pad = new Botan::Null_Padding();
+				with_pkcs7_padding = false;
 			}
 			std::unique_ptr<Botan::BlockCipher> bc(Botan::BlockCipher::create(cipher_name));
-			Botan::Keyed_Filter* cipher = new Botan::Cipher_Mode_Filter(new Botan::ECB_Encryption(bc.release(),pad));
+			Botan::Keyed_Filter* cipher = new Botan::Cipher_Mode_Filter(new Botan::ECB_Encryption(bc.release(), with_pkcs7_padding));
 			cipher->set_key(botanKey);
 			cryption = new Botan::Pipe(cipher);
-#else
-			cryption = new Botan::Pipe(Botan::get_cipher(cipherName, botanKey, Botan::ENCRYPTION));
-#endif
 		}
-#ifdef WITH_AES_GCM
 		else if (mode == SymMode::GCM)
 		{
 			Botan::AEAD_Mode* aead = Botan::get_aead(cipherName, Botan::ENCRYPTION);
@@ -184,7 +199,6 @@ bool BotanSymmetricAlgorithm::encryptInit(const SymmetricKey* key, const SymMode
 			filter->set_iv(botanIV);
 			cryption = new Botan::Pipe(filter);
 		}
-#endif
 		else
 		{
 			Botan::InitializationVector botanIV = Botan::InitializationVector(IV.const_byte_str(), IV.size());
@@ -392,28 +406,23 @@ bool BotanSymmetricAlgorithm::decryptInit(const SymmetricKey* key, const SymMode
 		Botan::SymmetricKey botanKey = Botan::SymmetricKey(key->getKeyBits().const_byte_str(), key->getKeyBits().size());
 		if (mode == SymMode::ECB)
 		{
-#if BOTAN_VERSION_CODE >= BOTAN_VERSION_CODE_FOR(2,0,0)
 			// ECB cipher mode was dropped in Botan 2.0
-			const std::vector<std::string> algo_parts = Botan::split_on(cipherName, '/');
+			const std::vector<std::string> algo_parts = split_on_delim(cipherName, '/');
 			const std::string cipher_name = algo_parts[0];
-			Botan::BlockCipherModePaddingMethod* pad;
+			bool with_pkcs7_padding;
 			if (algo_parts.size() == 3 && algo_parts[2] == "PKCS7")
 			{
-				pad = new Botan::PKCS7_Padding();
+				with_pkcs7_padding = true;
 			}
 			else
 			{
-				pad = new Botan::Null_Padding();
+				with_pkcs7_padding = false;
 			}
 			std::unique_ptr<Botan::BlockCipher> bc(Botan::BlockCipher::create(cipher_name));
-			Botan::Keyed_Filter* cipher = new Botan::Cipher_Mode_Filter(new Botan::ECB_Decryption(bc.release(),pad));
+			Botan::Keyed_Filter* cipher = new Botan::Cipher_Mode_Filter(new Botan::ECB_Decryption(bc.release(),with_pkcs7_padding));
 			cipher->set_key(botanKey);
 			cryption = new Botan::Pipe(cipher);
-#else
-			cryption = new Botan::Pipe(Botan::get_cipher(cipherName, botanKey, Botan::DECRYPTION));
-#endif
 		}
-#ifdef WITH_AES_GCM
 		else if (mode == SymMode::GCM)
 		{
 			Botan::AEAD_Mode* aead = Botan::get_aead(cipherName, Botan::DECRYPTION);
@@ -425,7 +434,6 @@ bool BotanSymmetricAlgorithm::decryptInit(const SymmetricKey* key, const SymMode
 			filter->set_iv(botanIV);
 			cryption = new Botan::Pipe(filter);
 		}
-#endif
 		else
 		{
 			Botan::InitializationVector botanIV = Botan::InitializationVector(IV.const_byte_str(), IV.size());
