@@ -32,6 +32,10 @@
 
 #include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/ui/text/TestRunner.h>
+#include <cppunit/TestResult.h>
+#include <cppunit/TestResultCollector.h>
+#include <cppunit/XmlOutputter.h>
+#include <fstream>
 
 #include "config.h"
 #include "MutexFactory.h"
@@ -44,12 +48,18 @@ std::auto_ptr<MutexFactory> MutexFactory::instance(NULL);
 
 int main(int /*argc*/, char** /*argv*/)
 {
+	CppUnit::TestResult controller;
+	CppUnit::TestResultCollector result;
 	CppUnit::TextUi::TestRunner runner;
+	controller.addListener(&result);
 	CppUnit::TestFactoryRegistry &registry = CppUnit::TestFactoryRegistry::getRegistry();
 
 	runner.addTest(registry.makeTest());
-	bool wasSucessful = runner.run();
+	runner.run(controller);
 
-	return wasSucessful ? 0 : 1;
+	std::ofstream xmlFileOut("test-results.xml");
+	CppUnit::XmlOutputter xmlOut(&result, xmlFileOut);
+	xmlOut.write();
+
+	return result.wasSuccessful() ? 0 : 1;
 }
-
